pyrasa.utils.peak\_utils.get\_peak\_params
==========================================

.. currentmodule:: pyrasa.utils.peak_utils

.. autofunction:: get_peak_params

.. _sphx_glr_backreferences_pyrasa.utils.peak_utils.get_peak_params:

.. minigallery:: pyrasa.utils.peak_utils.get_peak_params
    :add-heading: